mercurial/cmdutil.py
changeset 7807 bd8f44638847
parent 7779 e899ead7b8ae
child 7878 8c09952cd39a
--- a/mercurial/cmdutil.py	Sat Feb 28 12:25:14 2009 +0100
+++ b/mercurial/cmdutil.py	Sat Feb 28 12:38:45 2009 +0100
@@ -940,10 +940,10 @@
     raise util.Abort(_("revision matching date not found"))
 
 def walkchangerevs(ui, repo, pats, change, opts):
-    '''Iterate over files and the revs they changed in.
+    '''Iterate over files and the revs in which they changed.
 
     Callers most commonly need to iterate backwards over the history
     it is interested in.  Doing so has awful (quadratic-looking)
     performance, so we use iterators in a "windowed" way.
 
     We walk a window of revisions in the desired order.  Within the
@@ -940,10 +940,10 @@
 
     Callers most commonly need to iterate backwards over the history
-    it is interested in.  Doing so has awful (quadratic-looking)
+    in which they are interested. Doing so has awful (quadratic-looking)
     performance, so we use iterators in a "windowed" way.
 